pub fn written_size<S, R>(comp: &Compound<S>, root_name: &R) -> usizeExpand description
Returns the number of bytes that will be written when
to_binary is called with this compound and root name.
If to_binary results in Ok, the exact number of bytes
reported by this function will have been written. If the result is
Err, then the reported count will be greater than or equal to the
number of bytes that have actually been written.